<?php

require_once __DIR__.'/constants.php';

//
//from http://stackoverflow.com/questions/834303/startswith-and-endswith-functions-in-php
function endsWith($haystack, $needle) {
    // search forward starting from end minus needle length characters
    return $needle === "" || (($temp = strlen($haystack) - strlen($needle)) >= 0 && strpos($haystack, $needle, $temp) !== false);
}

//$expectedPath must mactch the ending of $fullPath
//e.g. isPath("/test", ".../var/xxx/test") -> true
// isPath("/test", "/var/.../test/") -> false
function pathMatched($expectedPath, $fullPath) {
	//$_SERVER['REQUEST_URI']
	return endsWith($fullPath, $expectedPath);
}

/**
 * connects to the given db
 * @param string $server the server e.g. localhost
 * @param string $dbName the db name e.g. myDb
 * @param string $user the user
 * @param string $pw the password
 * @return PDO the connection or NULL
 */
function connectToDb($server, $dbName,  $user, $pw) {
    $conn = NULL;
    try {
        $conn = new PDO("mysql:host=" . $server . ";dbname=" . $dbName . ";" , $user, $pw);
        // set the PDO error mode to exception
        $conn->setAttribute(PDO::ATTR_ERRMODE, PDO::ERRMODE_EXCEPTION);
        //echo "Connected successfully"; 
    } catch(PDOException $e) {
        # response is handled in api file (when $conn is NULL)
        debug("Connection failed: " . $e->getMessage());
        $conn = NULL;
    }
    return $conn;
}

/**
 * executes the given sql against the given connection
 * @param PDO $conn the connection to use
 * @param string $sql the sql to execute
 * @param array $params the params (array, e.g. array(":tag"=>$tag, ":value"=>$value,":time"=> $time);)
 * @return string ok or NULL on error
 */
function executeSql($conn, $sql, $params) {

    global $status_code_DbIssue;
    global $isDebug;
    //$stmt = $conn->prepare("INSERT INTO MyGuests (firstname, lastname, email) 
    //$stmt->bindParam(':firstname', $firstname);
    try {
        $cmd = $conn->prepare($sql);

        foreach ($params as $name => $value) {
            $cmd->bindValue($name, $value);
        }
        
        $cmd->execute();
        
    } catch(Exception $e) {

        if ($isDebug) {
            output($status_code_DbIssue, "execute sql: " . $sql . " failed: " . $e->getMessage());
        } else {
            output($status_code_DbIssue, "error executing sql statement");
        }

        return NULL;
    }
    
    return "ok";
}

/**
 * executes the sql and returns all fetched rows (array)
 * @param PDO $conn the connection to use
 * @param string $sql the sql to execute
 * @param array $params the params (array, e.g. array(":tag"=>$tag, ":value"=>$value,":time"=> $time);)
 * @return array the fetched rows as array (e.g. to get a cell $result[0]['Column']) or NULL
 */
function executeSqlAndReturnValue($conn, $sql, $params) {

    global $isDebug;
    global $status_code_DbIssue;

    try {
       
        $cmd = $conn->prepare($sql);

        foreach ($params as $name => $value) {
            $cmd->bindValue($name, $value);
        }
        
        #var_dump($cmd);
        
        $cmd->execute();
        $rows = $cmd->fetchAll();
        
        if ($rows === FALSE) {
            return NULL;
        }
       
       return $rows;
       
    } catch(Exception $e) {

        if ($isDebug) {
            output($status_code_DbIssue, "executeSqlAndReturnValue: " . $sql . " failed: " . $e->getMessage());
        } else {
            output($status_code_DbIssue, "error executing sql statement and getting result");
        }

        return NULL;
    }
    
}
